@@ -156,35 +156,41 @@ class TestCreditCard(unittest.TestCase):
         self.assertEqual(None, result.credit_card.billing_address)
 
 
-    def test_create_with_card_verification_returns_risk_data(self):
-        customer = Customer.create().customer
-        result = CreditCard.create({
-            "customer_id": customer.id,
-            "number": "4000111111111115",
-            "expiration_date": "05/2014",
-            "options": {"verify_card": True}
-        })
+    def test_unsuccessful_create_with_card_verification_returns_risk_data(self):
+        with AdvancedFraudIntegrationMerchant():
+            customer = Customer.create().customer
+            result = CreditCard.create({
+                "customer_id": customer.id,
+                "number": "4000111111111115",
+                "expiration_date": "05/2014",
+                "options": {"verify_card": True},
+                "device_session_id": "abc123"
+            })
 
-        self.assertFalse(result.is_success)
-        verification = result.credit_card_verification
-        self.assertIsInstance(verification.risk_data, RiskData)
-        self.assertEqual(None, verification.risk_data.id)
-        self.assertEqual("Not Evaluated", verification.risk_data.decision)
+            self.assertFalse(result.is_success)
+            verification = result.credit_card_verification
+            self.assertIsInstance(verification.risk_data, RiskData)
+            self.assertTrue(hasattr(verification.risk_data, 'id'))
+            self.assertEqual("Approve", verification.risk_data.decision)
+            self.assertTrue(hasattr(verification.risk_data, 'device_data_captured'))
 
     def test_successful_create_with_card_verification_returns_risk_data(self):
-        customer = Customer.create().customer
-        result = CreditCard.create({
-            "customer_id": customer.id,
-            "number": "4111111111111111",
-            "expiration_date": "05/2014",
-            "options": {"verify_card": True}
-        })
+        with AdvancedFraudIntegrationMerchant():
+            customer = Customer.create().customer
+            result = CreditCard.create({
+                "customer_id": customer.id,
+                "number": "4111111111111111",
+                "expiration_date": "05/2014",
+                "options": {"verify_card": True},
+                "device_session_id": "abc123"
+            })
 
-        self.assertTrue(result.is_success)
-        verification = result.credit_card.verification
-        self.assertIsInstance(verification.risk_data, RiskData)
-        self.assertEqual(None, verification.risk_data.id)
-        self.assertEqual("Not Evaluated", verification.risk_data.decision)
+            self.assertTrue(result.is_success)
+            verification = result.credit_card.verification
+            self.assertIsInstance(verification.risk_data, RiskData)
+            self.assertTrue(hasattr(verification.risk_data, 'id'))
+            self.assertEqual("Approve", verification.risk_data.decision)
+            self.assertTrue(hasattr(verification.risk_data, 'device_data_captured'))
 
     def test_create_with_card_verification(self):
         customer = Customer.create().customer
@@ -398,7 +404,7 @@ class TestCreditCard(unittest.TestCase):
 
         self.assertTrue(result.is_success)
         self.assertEqual("411111", result.credit_card.bin)
-        self.assertTrue(result.credit_card.venmo_sdk)
+        self.assertFalse(result.credit_card.venmo_sdk)
 
     def test_create_with_invalid_venmo_sdk_payment_method_code(self):
         customer = Customer.create().customer
@@ -454,7 +460,7 @@ class TestCreditCard(unittest.TestCase):
             }
         })
         self.assertTrue(result.is_success)
-        self.assertTrue(result.credit_card.venmo_sdk)
+        self.assertFalse(result.credit_card.venmo_sdk)
 
     def test_create_with_invalid_venmo_sdk_session(self):
         customer = Customer.create().customer
