@@ -196,7 +196,14 @@ class TestCustomer(unittest.TestCase):
         self.assertIsInstance(customer.venmo_accounts[0], VenmoAccount)
 
     def test_create_with_us_bank_account_nonce(self):
-        result = Customer.create({"payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce()})
+        result = Customer.create({
+            "payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce(),
+            "credit_card": {
+                "options": {
+                    "verification_merchant_account_id": TestHelper.us_bank_merchant_account_id
+                }
+            }
+        })
         self.assertTrue(result.is_success)
 
         customer = result.customer
@@ -243,6 +250,20 @@ class TestCustomer(unittest.TestCase):
                     "custom_field": "custom merchant field",
                     "description": "merchant description",
                     "amount": "1.23",
+                    "shipping": {
+                        "first_name": "Andrew",
+                        "last_name": "Mason",
+                        "company": "Braintree",
+                        "street_address": "456 W Main St",
+                        "extended_address": "Apt 2F",
+                        "locality": "Bartlett",
+                        "region": "IL",
+                        "postal_code": "60103",
+                        "country_name": "Mexico",
+                        "country_code_alpha2": "MX",
+                        "country_code_alpha3": "MEX",
+                        "country_code_numeric": "484"
+                    },
                 },
             },
         })
@@ -469,7 +490,7 @@ class TestCustomer(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertTrue(result.customer.credit_cards[0].venmo_sdk)
+        self.assertFalse(result.customer.credit_cards[0].venmo_sdk)
 
     def test_create_with_venmo_sdk_payment_method_code(self):
         result = Customer.create({
@@ -535,7 +556,12 @@ class TestCustomer(unittest.TestCase):
 
     def test_find_customer_with_us_bank_account(self):
         customer = Customer.create({
-            "payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce()
+            "payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce(),
+            "credit_card": {
+                "options": {
+                    "verification_merchant_account_id": TestHelper.us_bank_merchant_account_id
+                }
+            }
         }).customer
 
         found_customer = Customer.find(customer.id)
@@ -549,6 +575,72 @@ class TestCustomer(unittest.TestCase):
     def test_find_with_invalid_customer(self):
         Customer.find("badid")
 
+    def test_find_customer_with_all_filterable_associations_filtered_out(self):
+        customer = Customer.create({
+            "custom_fields": {
+                "store_me": "custom value"
+            }
+        }).customer
+        credit_card = CreditCard.create({
+            "customer_id": customer.id,
+            "number": "4111111111111111",
+            "expiration_date": "05/2014",
+            "billing_address": {
+                "street_address": "123 Abc Way",
+                "locality": "Chicago",
+                "region": "Illinois",
+                "postal_code": "60622",
+                "country_name": "United States of America"
+            }
+        }).credit_card
+        subscription_id = "id_" + str(random.randint(1, 1000000))
+        subscription = Subscription.create({
+            "id": subscription_id,
+            "plan_id": "integration_trialless_plan",
+            "payment_method_token": credit_card.token,
+            "price": Decimal("1.00")
+        }).subscription
+
+        found_customer = Customer.find(customer.id, "customernoassociations")
+        self.assertEqual(len(found_customer.credit_cards), 0)
+        self.assertEqual(len(found_customer.payment_methods), 0)
+        self.assertEqual(len(found_customer.addresses), 0)
+        self.assertEqual(len(found_customer.custom_fields), 0)
+
+    def test_find_customer_with_nested_filterable_associations_filtered_out(self):
+        customer = Customer.create({
+            "custom_fields": {
+                "store_me": "custom value"
+            }
+        }).customer
+        credit_card = CreditCard.create({
+            "customer_id": customer.id,
+            "number": "4111111111111111",
+            "expiration_date": "05/2014",
+            "billing_address": {
+                "street_address": "123 Abc Way",
+                "locality": "Chicago",
+                "region": "Illinois",
+                "postal_code": "60622",
+                "country_name": "United States of America"
+            }
+        }).credit_card
+        subscription_id = "id_" + str(random.randint(1, 1000000))
+        subscription = Subscription.create({
+            "id": subscription_id,
+            "plan_id": "integration_trialless_plan",
+            "payment_method_token": credit_card.token,
+            "price": Decimal("1.00")
+        }).subscription
+
+        found_customer = Customer.find(customer.id, "customertoplevelassociations")
+        self.assertEqual(len(found_customer.credit_cards), 1)
+        self.assertEqual(len(found_customer.credit_cards[0].subscriptions), 0)
+        self.assertEqual(len(found_customer.payment_methods), 1)
+        self.assertEqual(len(found_customer.payment_methods[0].subscriptions), 0)
+        self.assertEqual(len(found_customer.addresses), 1)
+        self.assertEqual(len(found_customer.custom_fields), 1)
+
     def test_update_with_valid_options(self):
         customer = Customer.create({
             "first_name": "Joe",
@@ -762,6 +854,50 @@ class TestCustomer(unittest.TestCase):
         self.assertEqual(1, len(paypal_account_errors))
         self.assertEqual(ErrorCodes.PayPalAccount.CannotVaultOneTimeUsePayPalAccount, paypal_account_errors[0].code)
 
+
+    def test_update_with_paypal_order_nonce(self):
+        customer = Customer.create().customer
+
+        http = ClientApiHttp.create()
+        status_code, payment_method_nonce = http.get_paypal_nonce({
+            "intent": "order",
+            "payment-token": "fake-paypal-payment-token",
+            "payer-id": "fake-paypal-payer-id"
+        })
+
+        result = Customer.update(customer.id, {
+            "payment_method_nonce": payment_method_nonce,
+            "options": {
+                "paypal": {
+                    "payee_email": "payee@example.com",
+                    "order_id": "merchant-order-id",
+                    "custom_field": "custom merchant field",
+                    "description": "merchant description",
+                    "amount": "1.23",
+                    "shipping": {
+                        "first_name": "Andrew",
+                        "last_name": "Mason",
+                        "company": "Braintree",
+                        "street_address": "456 W Main St",
+                        "extended_address": "Apt 2F",
+                        "locality": "Bartlett",
+                        "region": "IL",
+                        "postal_code": "60103",
+                        "country_name": "Mexico",
+                        "country_code_alpha2": "MX",
+                        "country_code_alpha3": "MEX",
+                        "country_code_numeric": "484"
+                    },
+                },
+            },
+        })
+
+        self.assertTrue(result.is_success)
+        customer = result.customer
+        self.assertNotEqual(None, customer.paypal_accounts[0])
+        self.assertEqual(1, len(customer.paypal_accounts))
+        self.assertIsInstance(customer.paypal_accounts[0], PayPalAccount)
+
     def test_update_with_nested_verification_amount(self):
         customer = Customer.create({
             "first_name": "Joe",
