@@ -43,6 +43,20 @@ class TestPaymentMethod(unittest.TestCase):
                     "custom_field": "custom merchant field",
                     "description": "merchant description",
                     "amount": "1.23",
+                    "shipping": {
+                        "first_name": "Andrew",
+                        "last_name": "Mason",
+                        "company": "Braintree",
+                        "street_address": "456 W Main St",
+                        "extended_address": "Apt 2F",
+                        "locality": "Bartlett",
+                        "region": "IL",
+                        "postal_code": "60103",
+                        "country_name": "Mexico",
+                        "country_code_alpha2": "MX",
+                        "country_code_alpha3": "MEX",
+                        "country_code_numeric": "484"
+                    },
                 },
             },
         })
@@ -52,11 +66,52 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEqual(PayPalAccount, created_account.__class__)
         self.assertEqual("bt_buyer_us@paypal.com", created_account.email)
         self.assertNotEqual(created_account.image_url, None)
+        self.assertNotEqual(created_account.payer_id, None)
 
         found_account = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_account)
         self.assertEqual(created_account.token, found_account.token)
         self.assertEqual(created_account.customer_id, found_account.customer_id)
+        self.assertEqual(created_account.payer_id, found_account.payer_id)
+
+    def test_create_with_paypal_refresh_token(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "paypal_refresh_token": "PAYPAL_REFRESH_TOKEN",
+        })
+
+        self.assertTrue(result.is_success)
+        created_account = result.payment_method
+        self.assertEqual(PayPalAccount, created_account.__class__)
+        self.assertEqual("B_FAKE_ID", created_account.billing_agreement_id)
+        self.assertNotEqual(created_account.payer_id, None)
+
+        found_account = PaymentMethod.find(result.payment_method.token)
+        self.assertNotEqual(None, found_account)
+        self.assertEqual(created_account.token, found_account.token)
+        self.assertEqual(created_account.customer_id, found_account.customer_id)
+        self.assertEqual(created_account.billing_agreement_id, found_account.billing_agreement_id)
+        self.assertEqual(created_account.payer_id, found_account.payer_id)
+
+    def test_create_with_paypal_refresh_token_without_upgrade(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "paypal_refresh_token": "PAYPAL_REFRESH_TOKEN",
+            "paypal_vault_without_upgrade": True,
+        })
+
+        self.assertTrue(result.is_success)
+        created_account = result.payment_method
+        self.assertEqual(PayPalAccount, created_account.__class__)
+        self.assertEqual(created_account.billing_agreement_id, None)
+
+        found_account = PaymentMethod.find(result.payment_method.token)
+        self.assertNotEqual(None, found_account)
+        self.assertEqual(created_account.token, found_account.token)
+        self.assertEqual(created_account.customer_id, found_account.customer_id)
+        self.assertEqual(created_account.billing_agreement_id, found_account.billing_agreement_id)
 
     def test_create_returns_validation_failures(self):
         http = ClientApiHttp.create()
@@ -148,39 +203,6 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEqual(found_credit_card.token, created_credit_card.token)
         self.assertEqual(found_credit_card.customer_id, created_credit_card.customer_id)
 
-    def test_create_with_europe_bank_account_nonce(self):
-        config = Configuration.instantiate()
-        customer_id = Customer.create().customer.id
-        token = TestHelper.generate_decoded_client_token({"customer_id": customer_id, "sepa_mandate_type": EuropeBankAccount.MandateType.Business})
-        authorization_fingerprint = json.loads(token)["authorizationFingerprint"]
-        client_api = ClientApiHttp(config, {
-            "authorization_fingerprint": authorization_fingerprint,
-            "shared_customer_identifier": "fake_identifier",
-            "shared_customer_identifier_type": "testing"
-        })
-        nonce = client_api.get_europe_bank_account_nonce({
-            "locale": "de-DE",
-            "bic": "DEUTDEFF",
-            "iban": "DE89370400440532013000",
-            "accountHolderName": "Baron Von Holder",
-            "billingAddress": {"region": "Hesse", "country_name": "Germany"}
-        })
-
-        self.assertNotEqual(nonce, None)
-        result = PaymentMethod.create({
-            "customer_id": customer_id,
-            "payment_method_nonce": nonce
-        })
-
-        self.assertTrue(result.is_success)
-        self.assertNotEqual(result.payment_method.image_url, None)
-        self.assertEqual(customer_id, result.payment_method.customer_id)
-        found_bank_account = PaymentMethod.find(result.payment_method.token)
-
-        self.assertNotEqual(found_bank_account, None)
-        self.assertEqual("DEUTDEFF", found_bank_account.bic)
-        self.assertEqual(EuropeBankAccount, found_bank_account.__class__)
-
     def test_create_with_fake_apple_pay_nonce(self):
         customer_id = Customer.create().customer.id
         result = PaymentMethod.create({
@@ -216,8 +238,8 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertEqual(customer_id, android_pay_card.customer_id)
         self.assertEqual(CreditCard.CardType.Discover, android_pay_card.virtual_card_type)
         self.assertEqual("1117", android_pay_card.virtual_card_last_4)
-        self.assertEqual("Visa 1111", android_pay_card.source_description)
-        self.assertEqual(CreditCard.CardType.Visa, android_pay_card.source_card_type)
+        self.assertEqual("Discover 1111", android_pay_card.source_description)
+        self.assertEqual(CreditCard.CardType.Discover, android_pay_card.source_card_type)
         self.assertEqual("1111", android_pay_card.source_card_last_4)
         self.assertEqual("1117", android_pay_card.last_4)
         self.assertEqual(CreditCard.CardType.Discover, android_pay_card.card_type)
@@ -299,36 +321,13 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertRegexpMatches(venmo_account.image_url, r"\.png")
         self.assertEqual(customer_id, venmo_account.customer_id)
 
-    def test_create_with_us_bank_account_nonce(self):
+    def test_payment_method_create_with_europe_bank_account_nonce_raises(self):
         customer_id = Customer.create().customer.id
-        result = PaymentMethod.create({
+        self.assertRaises(ServerError, PaymentMethod.create, {
             "customer_id": customer_id,
-            "payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce()
+            "payment_method_nonce": Nonces.Europe,
         })
 
-        self.assertTrue(result.is_success)
-        us_bank_account = result.payment_method
-        self.assertIsInstance(us_bank_account, UsBankAccount)
-        self.assertEqual(us_bank_account.routing_number, "021000021")
-        self.assertEqual(us_bank_account.last_4, "1234")
-        self.assertEqual(us_bank_account.account_type, "checking")
-        self.assertEqual(us_bank_account.account_holder_name, "Dan Schulman")
-        self.assertTrue(re.match(r".*CHASE.*", us_bank_account.bank_name))
-        self.assertEqual(us_bank_account.default, True)
-        self.assertEqual(us_bank_account.ach_mandate.text, "cl mandate text")
-        self.assertIsInstance(us_bank_account.ach_mandate.accepted_at, datetime)
-
-    def test_create_fails_with_invalid_us_bank_account_nonce(self):
-        customer_id = Customer.create().customer.id
-        result = PaymentMethod.create({
-            "customer_id": customer_id,
-            "payment_method_nonce": TestHelper.generate_invalid_us_bank_account_nonce()
-        })
-
-        self.assertFalse(result.is_success)
-        error_code = result.errors.for_object("payment_method").on("payment_method_nonce")[0].code
-        self.assertEqual(ErrorCodes.PaymentMethod.PaymentMethodNonceUnknown, error_code)
-
     def test_create_with_abstract_payment_method_nonce(self):
         customer_id = Customer.create().customer.id
         result = PaymentMethod.create({
@@ -1110,7 +1109,7 @@ class CreditCardForwardingTest(unittest.TestCase):
             "integration_private_key"
         )
 
-    def test_forward(self):
+    def test_forward_raises_exception(self):
         customer = Customer.create().customer
         credit_card_result = CreditCard.create({
             "customer_id": customer.id,
@@ -1120,29 +1119,7 @@ class CreditCardForwardingTest(unittest.TestCase):
         self.assertTrue(credit_card_result.is_success)
         source_merchant_card = credit_card_result.credit_card
 
-        forward_result = CreditCard.forward(
-            source_merchant_card.token,
-            "integration_merchant_id"
-        )
-        self.assertTrue(forward_result.is_success)
-
-        braintree.Configuration.configure(
-            braintree.Environment.Development,
-            "integration_merchant_id",
-            "integration_public_key",
-            "integration_private_key"
-        )
-        customer = Customer.create().customer
-        credit_card_result = CreditCard.create({
-            "customer_id": customer.id,
-            "payment_method_nonce": forward_result.nonce
-        })
-        self.assertTrue(credit_card_result.is_success)
-        receiving_merchant_card = credit_card_result.credit_card
-        self.assertEqual(source_merchant_card.bin, receiving_merchant_card.bin)
-        self.assertEqual(source_merchant_card.last_4, receiving_merchant_card.last_4)
-        self.assertEqual(source_merchant_card.expiration_month, receiving_merchant_card.expiration_month)
-        self.assertEqual(source_merchant_card.expiration_year, receiving_merchant_card.expiration_year)
+        self.assertRaises(NotFoundError, CreditCard.forward, source_merchant_card.token, "integration_merchant_id")
 
     def test_forward_invalid_token_raises_exception(self):
         self.assertRaises(NotFoundError, CreditCard.forward, "invalid", "integration_merchant_id")
