@@ -6,6 +6,7 @@ import sys
 import unittest
 import warnings
 import subprocess
+import time
 
 if sys.version_info[0] == 2:
     from urllib import urlencode, quote_plus
@@ -26,6 +27,7 @@ from nose.tools import raises
 
 from braintree import *
 from braintree.exceptions import *
+from braintree.test.credit_card_numbers import CreditCardNumbers
 from braintree.test.nonces import Nonces
 from braintree.testing_gateway import *
 from braintree.util import *
@@ -61,18 +63,32 @@ def reset_braintree_configuration():
     )
 reset_braintree_configuration()
 
+class AdvancedFraudIntegrationMerchant:
+    def __enter__(self):
+        Configuration.configure(
+            Environment.Development,
+            "advanced_fraud_integration_merchant_id",
+            "advanced_fraud_integration_public_key",
+            "advanced_fraud_integration_private_key"
+        )
+
+    def __exit__(self, type, value, trace):
+        reset_braintree_configuration()
+
 def showwarning(*_):
     pass
 warnings.showwarning = showwarning
 
 class TestHelper(object):
-
     default_merchant_account_id = "sandbox_credit_card"
     non_default_merchant_account_id = "sandbox_credit_card_non_default"
     non_default_sub_merchant_account_id = "sandbox_sub_merchant_account"
     three_d_secure_merchant_account_id = "three_d_secure_merchant_account"
     fake_amex_direct_merchant_account_id = "fake_amex_direct_usd"
     fake_venmo_account_merchant_account_id = "fake_first_data_venmo_account"
+    us_bank_merchant_account_id = "us_bank_merchant_account"
+    another_us_bank_merchant_account_id = "another_us_bank_merchant_account"
+
     add_on_discount_plan = {
          "description": "Plan for integration tests -- with add-ons and discounts",
          "id": "integration_plan_with_add_ons_and_discounts",
@@ -231,11 +247,11 @@ class TestHelper(object):
         return string
 
     @staticmethod
-    def generate_valid_us_bank_account_nonce():
+    def generate_valid_us_bank_account_nonce(routing_number="021000021", account_number="567891234"):
         client_token = json.loads(TestHelper.generate_decoded_client_token())
         headers = {
             "Content-Type": "application/json",
-            "Braintree-Version": "2015-11-01",
+            "Braintree-Version": "2016-10-07",
             "Authorization": "Bearer " + client_token["braintree_api"]["access_token"]
         }
         payload = {
@@ -247,9 +263,39 @@ class TestHelper(object):
                 "postal_code": "94112"
             },
             "account_type": "checking",
-            "routing_number": "021000021",
-            "account_number": "567891234",
-            "account_holder_name": "Dan Schulman",
+            "ownership_type": "personal",
+            "routing_number": routing_number,
+            "account_number": account_number,
+            "first_name": "Dan",
+            "last_name": "Schulman",
+            "ach_mandate": {
+                "text": "cl mandate text"
+            }
+        }
+        resp = requests.post(client_token["braintree_api"]["url"] + "/tokens", headers=headers, data=json.dumps(payload) )
+        respJson = json.loads(resp.text)
+        return respJson["data"]["id"]
+
+    @staticmethod
+    def generate_plaid_us_bank_account_nonce():
+        client_token = json.loads(TestHelper.generate_decoded_client_token())
+        headers = {
+            "Content-Type": "application/json",
+            "Braintree-Version": "2016-10-07",
+            "Authorization": "Bearer " + client_token["braintree_api"]["access_token"]
+        }
+        payload = {
+            "type": "plaid_public_token",
+            "public_token": "good",
+            "account_id": "plaid_account_id",
+            "ownership_type": "business",
+            "business_name": "PayPal, Inc.",
+            "billing_address": {
+                "street_address": "123 Ave",
+                "region": "CA",
+                "locality": "San Francisco",
+                "postal_code": "94112"
+            },
             "ach_mandate": {
                 "text": "cl mandate text"
             }
@@ -299,6 +345,33 @@ class TestHelper(object):
         response = gateway.config.http().post(url, params)
         return response["payment_method_nonce"]["nonce"]
 
+    @staticmethod
+    def create_disputed_transaction():
+        if hasattr(TestHelper, 'disputed_transaction'):
+            return TestHelper.disputed_transaction
+
+        disputed_transaction = Transaction.sale({
+            "amount": "10.00",
+            "credit_card": {
+                "number": CreditCardNumbers.Disputes.Chargeback,
+                "expiration_date": "04/2018"
+                }
+            })
+
+        for _ in range(1, 60):
+            transactions = Transaction.search([
+                TransactionSearch.id == disputed_transaction.transaction.id,
+                TransactionSearch.dispute_date == datetime.today()
+            ])
+
+            if transactions.maximum_size == 1:
+                TestHelper.disputed_transaction = transactions.first
+                return TestHelper.disputed_transaction
+            else:
+                time.sleep(1)
+
+        raise ValueError('Disputed transaction could not be found')
+
     @staticmethod
     def create_grant(gateway, params):
         config = gateway.config
@@ -381,7 +454,7 @@ class ClientApiHttp(Http):
     def __http_do(self, http_verb, path, params=None):
         http_strategy = self.config.http_strategy()
         request_body = json.dumps(params) if params else None
-        return http_strategy.http_do(http_verb, path, self.__headers(), (request_body, None))
+        return http_strategy.http_do(http_verb, path, self.__headers(), request_body)
 
     def set_authorization_fingerprint(self, authorization_fingerprint):
         self.options['authorization_fingerprint'] = authorization_fingerprint
@@ -446,21 +519,6 @@ class ClientApiHttp(Http):
 
         return [status_code, nonce]
 
-    def get_europe_bank_account_nonce(self, europe_bank_account_params):
-        params = {"sepa_mandate": europe_bank_account_params}
-        url = "/merchants/%s/client_api/v1/sepa_mandates" % self.config.merchant_id
-        if 'authorization_fingerprint' in self.options:
-            params['authorizationFingerprint'] = self.options['authorization_fingerprint']
-
-        status_code, response = self.post(url, params)
-        json_body = json.loads(response)
-
-        nonce = None
-        if status_code == 201:
-            nonce = json_body["europeBankAccounts"][0]["nonce"]
-
-        return nonce
-
     def __headers(self):
         return {
             "Content-type": "application/json",
