@@ -14,6 +14,18 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual(WebhookNotification.Kind.SubscriptionWentPastDue, notification.kind)
         self.assertEqual("my_id", notification.subscription.id)
         self.assertTrue((datetime.utcnow() - notification.timestamp).seconds < 10)
+        self.assertIsNone(notification.source_merchant_id)
+
+    def test_sample_notification_with_source_merchant_id(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.SubscriptionWentPastDue,
+            'my_id',
+            'my_source_merchant_id'
+        )
+
+        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
+
+        self.assertEqual('my_source_merchant_id', notification.source_merchant_id)
 
     @raises(InvalidSignatureError)
     def test_completely_invalid_signature(self):
@@ -58,7 +70,23 @@ class TestWebhooks(unittest.TestCase):
         else:
             self.assertFalse("raises exception")
 
-    def test_invalid_signature_when_contains_invalid_characters(self):
+    def test_parse_raise_exception_if_signature_is_blank(self):
+        try:
+            WebhookNotification.parse(None, "payload")
+        except InvalidSignatureError as e:
+            self.assertEqual("signature cannot be blank", str(e))
+        else:
+            self.assertFalse("raises exception")
+
+    def test_parse_raise_exception_if_payload_is_blank(self):
+        try:
+            WebhookNotification.parse("signature", None)
+        except InvalidSignatureError as e:
+            self.assertEqual("payload cannot be blank", str(e))
+        else:
+            self.assertFalse("raises exception")
+
+    def test_invalid_signature_when_bontains_invalid_characters(self):
         sample_notification = WebhookTesting.sample_notification(
             WebhookNotification.Kind.SubscriptionWentPastDue,
             "my_id"
@@ -339,6 +367,19 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual("abc123", notification.partner_merchant.partner_merchant_id)
         self.assertTrue((datetime.utcnow() - notification.timestamp).seconds < 10)
 
+    def test_builds_notification_for_oauth_access_revoked(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.OAuthAccessRevoked,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+
+        self.assertEqual(WebhookNotification.Kind.OAuthAccessRevoked, notification.kind)
+        self.assertEqual("my_id", notification.oauth_access_revocation.merchant_id)
+        self.assertEqual("oauth_application_client_id", notification.oauth_access_revocation.oauth_application_client_id)
+        self.assertTrue((datetime.utcnow() - notification.timestamp).seconds < 10)
+
     def test_builds_notification_for_connected_merchant_status_transitioned(self):
         sample_notification = WebhookTesting.sample_notification(
             WebhookNotification.Kind.ConnectedMerchantStatusTransitioned,
@@ -350,6 +391,7 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual(WebhookNotification.Kind.ConnectedMerchantStatusTransitioned, notification.kind)
         self.assertEqual("new_status", notification.connected_merchant_status_transitioned.status)
         self.assertEqual("my_id", notification.connected_merchant_status_transitioned.merchant_public_id)
+        self.assertEqual("my_id", notification.connected_merchant_status_transitioned.merchant_id)
         self.assertEqual("oauth_application_client_id", notification.connected_merchant_status_transitioned.oauth_application_client_id)
 
     def test_builds_notification_for_connected_merchant_paypal_status_changed(self):
@@ -363,6 +405,7 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual(WebhookNotification.Kind.ConnectedMerchantPayPalStatusChanged, notification.kind)
         self.assertEqual("link", notification.connected_merchant_paypal_status_changed.action)
         self.assertEqual("my_id", notification.connected_merchant_paypal_status_changed.merchant_public_id)
+        self.assertEqual("my_id", notification.connected_merchant_paypal_status_changed.merchant_id)
         self.assertEqual("oauth_application_client_id", notification.connected_merchant_paypal_status_changed.oauth_application_client_id)
 
     def test_builds_notification_for_subscription_charged_successfully(self):
@@ -437,3 +480,19 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual("10.00", ideal_payment.amount);
         self.assertEqual("https://example.com", ideal_payment.approval_url);
         self.assertEqual("1234567890", ideal_payment.ideal_transaction_id);
+
+    def test_granted_payment_instrument_update_webhook(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.GrantedPaymentInstrumentUpdate,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        update = notification.granted_payment_instrument_update
+
+        self.assertEqual(WebhookNotification.Kind.GrantedPaymentInstrumentUpdate, notification.kind)
+        self.assertEqual("vczo7jqrpwrsi2px", update.grant_owner_merchant_id)
+        self.assertEqual("cf0i8wgarszuy6hc", update.grant_recipient_merchant_id)
+        self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", update.payment_method_nonce)
+        self.assertEqual("abc123z", update.token)
+        self.assertEqual(["expiration-month", "expiration-year"], update.updated_fields)
